@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """Unit tests for phonenumbermatcher.py"""
 
 # Based on original Java code:
@@ -23,7 +22,7 @@ import unittest
 from phonenumbers import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 from phonenumbers import PhoneNumber, NumberFormat, phonenumberutil
 from phonenumbers import phonenumbermatcher, CountryCodeSource
-from phonenumbers.util import u
+from phonenumbers.util import prnt, u
 from .testmetadatatest import TestMetadataTestCase
 
 
@@ -96,8 +95,8 @@ class PhoneNumberMatchTest(unittest.TestCase):
         # Python version extra test
         self.assertEqual("PhoneNumberMatch(start=10, raw_string='1 800 234 45 67', "
                          "numobj=PhoneNumber(country_code=None, national_number=None, extension=None, "
-                         "italian_leading_zero=False, number_of_leading_zeros=None, "
-                         "country_code_source=None, preferred_domestic_carrier_code=None))", repr(match))
+                         "italian_leading_zero=None, number_of_leading_zeros=None, "
+                         "country_code_source=0, preferred_domestic_carrier_code=None))", repr(match))
 
 
 class NumberContext(object):
@@ -171,6 +170,8 @@ VALID_CASES = [NumberTest("65 02 53 00 00", "US"),
                NumberTest("03 0 -3 2 23 12 34", "DE"),
                NumberTest("(0)3 0 -3 2 23 12 34", "DE"),
                NumberTest("0 3 0 -3 2 23 12 34", "DE"),
+               # Fits an alternate pattern, but the leading digits don't match.
+               NumberTest("+52 332 123 23 23", "MX"),
                ]
 
 # Strings with number-like things that should only be found up to and
@@ -887,6 +888,10 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
                         NumberContext("As I said on 03/10/2011, you may call me at ", ""),
                         # With trailing numbers after a comma. The 45 should not be considered an extension.
                         NumberContext("", ", 45 days a year"),
+                        # When matching we don't consider semicolon along with legitimate extension
+                        # symbol to indicate an extension. The 7246433 should not be considered an
+                        # extension.
+                        NumberContext("", ";x 7246433"),
                         # With a postfix stripped off as it looks like the start of another number.
                         NumberContext("Call ", "/x12 more"),
                         ]
@@ -969,7 +974,7 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
         self.assertRaises(Exception, _limit, *(1, 0))
         self.assertRaises(Exception, _limit, *(2, 1))
         number = PhoneNumber(country_code=44, national_number=7912345678)
-        self.assertRaises(Exception, _verify, *(99, number, "12345678"))
+        self.assertRaises(Exception, _verify, *(99, number, "12345678", None))
         self.assertRaises(ValueError, PhoneNumberMatcher, *("text", "US"), **{"leniency": None})
         self.assertRaises(ValueError, PhoneNumberMatcher, *("text", "US"), **{"max_tries": -2})
         # Invalid country looks like national prefix is present (no way to tell)
